"""claude-runner: Reusable Claude Agent SDK wrapper with bug workarounds."""

from claude_runner._env import clean_claude_env
from claude_runner._patch import patch_sdk as _patch_sdk
from claude_runner._runner import run, run_sync
from claude_runner._types import RunResult

_patch_sdk()

__all__ = ["run", "run_sync", "RunResult", "clean_claude_env"]
